/*******************************************************************************

    HEASARC Database bulletin (HDBBUL) utility.

    AUTHOR: Song Yom (HSTX)
    DATE:   12/93

    MODIFICATION HISTORY:
    DATE    PROGRAMMER      DESCRIPTION
    ----    ----------      -----------
    12/94   Song Yom        added alternate host connection capability
    06/95   Song Yom        removed host dependent port number definition

*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "csioc.h"

#ifdef sun
#define EXIT_SUCCESS 0
#define EXIT_FAILURE 1
#endif

/*
    TCP/IP communication socket host name and port number
*/

#define HOST "legacy.gsfc.nasa.gov"
#define PORT 53255

/*
    Alternate host environment variable name
*/

#define HDBHOST "HDBHOST"

/*
    Maximum length of data buffer
*/

#define MAXLEN CSIOC_SIZE

#ifdef sun
main(argc,argv)
    int argc;
    char *argv[];
#else
main(int argc,char *argv[])
#endif
{
    int status = EXIT_FAILURE;
    int i;
    int sd;
    int length;
    char *ph;
    char host[MAXLEN];
    char buffer[MAXLEN];

/*
    Verify command line arguments, establish data communication connection
    with the server, construct and send the bulletin command buffer to the
    server, write all data and/or message(s) to standard output, and
    terminate the data communication connection with the server.
*/

    if (argc > 1)
    {
        if (ph = getenv(HDBHOST))
            strcpy(host,ph);
        else
            strcpy(host,HOST);
        if (csioc_connect(host,PORT,&sd) == CSIOC_SUCCESS)
        {
            buffer[0] = NULL;
            for (i = 1;i < argc;++i)
            {
                strcat(buffer,argv[i]);
                strcat(buffer," ");
            }
            buffer[strlen(buffer) - 1] = NULL;
            if (csioc_output(sd,buffer,strlen(buffer) + 1) ==
            CSIOC_SUCCESS && csioc_status(sd) == CSIOC_SUCCESS)
            {
                while (csioc_input(sd,buffer,&length) == CSIOC_SUCCESS)
                {
                    fprintf(stdout,"%s\n",buffer);
                    fflush(stdout);
                }
                status = EXIT_SUCCESS;
            }
            else
                fprintf(stdout,"%s\n",csioc_getstatus());
            csioc_disconnect(sd);
        }
        else
            fprintf(stdout,"%s: unable to establish connection\n",host);
    }
    else
        fprintf(stdout,"usage: %s command\n",argv[0]);

    exit(status);
}
